==> scummvm_2.7.0+dfsg.orig.tar.xz: scummvm-2.7.0+dfsg/engines/hpl1/engine/libraries/newton/core/dg.h <==
/* Copyright (c) <2003-2011> <Julio Jerez, Newton Game Dynamics>
*
* This software is provided 'as-is', without any express or implied
* warranty. In no event will the authors be held liable for any damages
* arising from the use of this software.
*
* Permission is granted to anyone to use this software for any purpose,
* including commercial applications, and to alter it and redistribute it
* freely, subject to the following restrictions:
*
* 1. The origin of this software must not be misrepresented; you must not
* claim that you wrote the original software. If you use this software
* in a product, an acknowledgment in the product documentation would be
* appreciated but is not required.
*
* 2. Altered source versions must be plainly marked as such, and must not be
* misrepresented as being the original software.
*
* 3. This notice may not be removed or altered from any source distribution.
*/

#if !defined(AFX_DG_H__FGRTY_5GR39H_98TQ__INCLUDED_)
#define AFX_DG_H__FGRTY_5GR39H_98TQ__INCLUDED_

#include "dgTypes.h"

#include "dgRef.h"
#include "dgCRC.h"
#include "dgRtti.h"
#include "dgList.h"
#include "dgTree.h"
#include "dgNode.h"
#include "dgHeap.h"
#include "dgArray.h"
#include "dgStack.h"
#include "dgDebug.h"
#include "dgGraph.h"
#include "dgPlane.h"
#include "dgGoogol.h"
#include "dgVector.h"
#include "dgMatrix.h"
#include "dgSphere.h"
#include "dgMemory.h"
#include "dgRandom.h"
#include "dgThreads.h"
#include "dgSPDMatrix.h"
#include "dgPolyhedra.h"
#include "dgPathFinder.h"
#include "dgRefCounter.h"
#include "dgQuaternion.h"
#include "dgConvexHull3d.h"
#include "dgConvexHull4d.h"
#include "dgIntersections.h"
#include "dgGeneralVector.h"
#include "dgGeneralMatrix.h"
#include "dgAABBPolygonSoup.h"
#include "dgSmallDeterminant.h"
#include "dgSimd_Instrutions.h"
#include "dgPolygonSoupBuilder.h"
#include "dgPolygonSoupDatabase.h"
#include "dgPolyhedraMassProperties.h"
#include "dgDelaunayTetrahedralization.h"

#endif

==> scummvm_2.9.1+dfsg.orig.tar.xz: scummvm-2.9.1/engines/hpl1/engine/libraries/newton/core/dg.h <==
/* Copyright (c) <2003-2011> <Julio Jerez, Newton Game Dynamics>
*
* This software is provided 'as-is', without any express or implied
* warranty. In no event will the authors be held liable for any damages
* arising from the use of this software.
*
* Permission is granted to anyone to use this software for any purpose,
* including commercial applications, and to alter it and redistribute it
* freely, subject to the following restrictions:
*
* 1. The origin of this software must not be misrepresented; you must not
* claim that you wrote the original software. If you use this software
* in a product, an acknowledgment in the product documentation would be
* appreciated but is not required.
*
* 2. Altered source versions must be plainly marked as such, and must not be
* misrepresented as being the original software.
*
* 3. This notice may not be removed or altered from any source distribution.
*/

#if !defined(AFX_DG_H__FGRTY_5GR39H_98TQ__INCLUDED_)
#define AFX_DG_H__FGRTY_5GR39H_98TQ__INCLUDED_

#include "dgTypes.h"

#include "dgRef.h"
#include "dgCRC.h"
#include "dgList.h"
#include "dgTree.h"
#include "dgNode.h"
#include "dgHeap.h"
#include "dgArray.h"
#include "dgStack.h"
#include "dgDebug.h"
#include "dgGraph.h"
#include "dgPlane.h"
#include "dgGoogol.h"
#include "dgVector.h"
#include "dgMatrix.h"
#include "dgSphere.h"
#include "dgMemory.h"
#include "dgRandom.h"
#include "dgThreads.h"
#include "dgSPDMatrix.h"
#include "dgPolyhedra.h"
#include "dgPathFinder.h"
#include "dgRefCounter.h"
#include "dgQuaternion.h"
#include "dgConvexHull3d.h"
#include "dgConvexHull4d.h"
#include "dgIntersections.h"
#include "dgGeneralVector.h"
#include "dgGeneralMatrix.h"
#include "dgAABBPolygonSoup.h"
#include "dgSmallDeterminant.h"
#include "dgSimd_Instrutions.h"
#include "dgPolygonSoupBuilder.h"
#include "dgPolygonSoupDatabase.h"
#include "dgPolyhedraMassProperties.h"
#include "dgDelaunayTetrahedralization.h"

#include "common/system.h"

class NewtonMesh;
class NewtonBody;
class NewtonWorld;
class NewtonJoint;
class NewtonMaterial;
class NewtonCollision;
class NewtonSceneProxy;
class NewtonbreakableComponentMesh;

typedef struct NewtonUserMeshCollisionCollideDesc NewtonUserMeshCollisionCollideDesc;
typedef struct NewtonUserMeshCollisionRayHitDesc NewtonUserMeshCollisionRayHitDesc;
typedef struct NewtonHingeSliderUpdateDesc NewtonHingeSliderUpdateDesc;

#ifdef __USE_DOUBLE_PRECISION__
#define dFloat double
#else
#define dFloat float
#endif

#endif
